@@ -1,6 +1,6 @@
 package Data::Validation::Constraints;
 
-use namespace::sweep;
+use namespace::autoclean;
 use charnames qw( :full );
 
 use Moo;
@@ -131,10 +131,6 @@ __END__
 
 Data::Validation::Constraints - Test data values for conformance with constraints
 
-=head1 Version
-
-Describes version v0.15.$Rev: 1 $ of L<Data::Validation::Constraints>
-
 =head1 Synopsis
 
    use Data::Validation::Constraints;
