@@ -1,6 +1,6 @@
 package Data::Validation::Exception;
 
-use namespace::sweep;
+use namespace::autoclean;
 
 use Moo;
 use Unexpected::Functions qw( has_exception );
